@@ -1,8 +1,13 @@
 /*
  * array-info - Array Controllers Informations
  * Copyright (C) 2002  Benoit Gaussen (ben@trez42.net)
+ * Copyright (c) 2009  Google, Inc (ragnark@google.com)
  *
  * $Log: compaq_data.h,v $
+ * Revision 1.2  2009/09/18 17:40:22  ragnark
+ * Add information about spare disks for cciss plugin
+ * Make array-info exit with exit code 1 if it detects problems with any of the logical volumes.
+ *
  * Revision 1.1  2002/07/29 16:50:19  trez42
  * Add plugin support
  * Change directory structure
@@ -36,6 +41,7 @@ typedef struct {
 	u_int8_t fault_tol;
 	u_int8_t status;
 	u_int32_t blks_to_recover;
+	u_int8_t spare_stat;
 } compaq_log_drive_t;
 
 typedef struct {
